# SMQTK - Core

## Intent
Provide the basic underpinnings for developing interfaces that have built-in
implementation discovery and factory construction from configuration.

## Documentation
You can build the sphinx documentation locally for the most up-to-date 
reference:
```bash
# Install dependencies
pip install -r requirements.txt 
# Navigate to the documentation root.
cd docs
# Build the docs.
make html
# Open in your favorite browser!
firefox _build/html/index.html
```
